@@ -842,8 +842,8 @@ int SaveFunction::calculate(MathStructure &mstruct, const MathStructure &vargs,
 			sarg2[1] = carg;
 			sarg_new[1] = carg;
 		}
-		if(CALCULATOR->functionNameTaken(vargs[1].symbol())) {
-			MathFunction *f = CALCULATOR->getActiveFunction(vargs[1].symbol(), true);
+		if(CALCULATOR->functionNameTaken(name)) {
+			MathFunction *f = CALCULATOR->getActiveFunction(name, true);
 			if(f && f->isLocal() && f->subtype() == SUBTYPE_USER_FUNCTION) {
 				if(!vargs[2].symbol().empty()) f->setCategory(vargs[2].symbol());
 				if(!vargs[3].symbol().empty()) f->setTitle(vargs[3].symbol());
@@ -866,6 +866,23 @@ int SaveFunction::calculate(MathStructure &mstruct, const MathStructure &vargs,
 		CALCULATOR->saveFunctionCalled();
 		return 1;
 	}
+	if(vargs[4].number().getBoolean()) {
+		if(mstruct.isComparison() && mstruct.comparisonType() == COMPARISON_EQUALS && (mstruct[0].isSymbolic() || (mstruct[0].isVariable() && !mstruct[0].variable()->isKnown()))) {
+			mstruct.setToChild(2, true);
+		} else if(mstruct.isLogicalAnd() && mstruct.size() > 0 && mstruct[0].isComparison() && mstruct[0].comparisonType() == COMPARISON_EQUALS && (mstruct[0][0].isSymbolic() || (mstruct[0][0].isVariable() && !mstruct[0][0].variable()->isKnown()))) {
+			bool b = true;
+			for(size_t i = 1; i < mstruct.size(); i++) {
+				if(!mstruct[i].isComparison() || mstruct[i].comparisonType() == COMPARISON_EQUALS) {
+					b = false;
+					break;
+				}
+			}
+			if(b) {
+				mstruct.setToChild(1, true);
+				mstruct.setToChild(2, true);
+			}
+		}
+	}
 	if(!CALCULATOR->variableNameIsValid(vargs[1].symbol())) {
 		CALCULATOR->error(true, _("Invalid variable name (%s)."), vargs[1].symbol().c_str(), NULL);
 		if(vargs[4].number().getBoolean()) return -1;
@@ -1004,7 +1021,7 @@ PlotFunction::PlotFunction() : MathFunction("plot", 1, -1) {
 	setCondition("\\y < \\z");
 	string str = _("Plots one or more expressions or vectors. Use a vector for the first argument to plot multiple series. Only the first argument is used for vector series. It is also possible to plot a matrix where each row is a pair of x and y values.");
 	str += "\n\n";
-	str += _("Additional arguments specifies various plot options. Enter the name of the option and the desried value, either separated by space or as separate arguments. For most options, the value can be omitted to enable a default active value. For options with named values, the option name can be omitted (otherwise the value can be replaced by an integer, representing the index of the value starting from zero). If the first option specified is a numerical value, this is interpreted as either sampling rate (for integers > 10) or step value.");
+	str += _("Additional arguments specify various plot options. Enter the name of the option and the desired value, either separated by space or as separate arguments. For most options, the value can be omitted to enable a default active value. For options with named values, the option name can be omitted (otherwise the value can be replaced by an integer, representing the index of the value starting from zero). If the first option specified is a numerical value, this is interpreted as either sampling rate (for integers > 10) or step value.");
 	str += "\n\n";
 	str += _("List of options:");
 	str += "\n";
